clj-service.core


call-fnclj

(call-fn {:keys [sfn farg] :as this} {:keys [args] :or {args []} :as clj-call})

env-cleanclj

(env-clean env)

exposeclj

(expose {:keys [services] :as this}
        {:keys [fun ctx permission] :as service-opts})

exposes one function this - created via start-executor service-opts: fun - fully qualified symbol fixed - a fixed args to be passed to a stateful function which is its first parameter

exposes one function 
this - created via start-executor
service-opts: 
   fun - fully qualified symbol
   fixed - a fixed args to be passed to a stateful function which is its first parameter
raw docstring

get-ext-servicesclj

(get-ext-services exts)

get-fargclj

(get-farg {:keys [env]} ctx)

get-serviceclj

(get-service {:keys [services] :as this} {:keys [fun] :as clj-call})

start-clj-servicesclj

(start-clj-services {:keys [env exts app-services]
                     :or {exts [] env {} app-services []}})

starts the clj-services :services - a vec of service-definition maps :env - the environment that gets (entirely or modified passed to a service that is stateful)

starts the clj-services
:services - a vec of service-definition maps
:env - the environment that gets (entirely or modified passed to a service that is stateful)
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries