(start-ap logger write service {:keys [id] :as clj-call})(start-clj logger write service {:keys [id] :as clj-call})(start-executing logger
write
{:keys [mode] :as service}
{:keys [id] :as clj-call})returns a missionary task which can execute the clj-call
returns a missionary task which can execute the clj-call
(start-sp logger write service {:keys [id] :as clj-call})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |