(call-fn {:keys [sfn farg] :as this} {:keys [args] :or {args []} :as clj-call})(env-clean env)(expose {:keys [services] :as this}
{:keys [fun ctx permission] :as service-opts})exposes one function this - created via start-executor service-opts: fun - fully qualified symbol fixed - a fixed args to be passed to a stateful function which is its first parameter
exposes one function this - created via start-executor service-opts: fun - fully qualified symbol fixed - a fixed args to be passed to a stateful function which is its first parameter
(get-ext-services exts)(get-farg {:keys [env]} ctx)(get-service {:keys [services] :as this} {:keys [fun] :as clj-call})(start-executor {:keys [env exts app-services]
:or {exts [] env {} app-services []}})starts the executor service :services - a vec of service-definition maps :env - the environment that gets (entirely or modified passed to a service that is stateful)
starts the executor service :services - a vec of service-definition maps :env - the environment that gets (entirely or modified passed to a service that is stateful)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |