clj-service.runner


start-apclj

(start-ap logger write service {:keys [id] :as clj-call})

start-cljclj

(start-clj logger write service {:keys [id] :as clj-call})

start-executingclj

(start-executing logger
                 write
                 {:keys [mode] :as service}
                 {:keys [id] :as clj-call})

returns a missionary task which can execute the clj-call

returns a missionary task which can execute the clj-call
raw docstring

start-spclj

(start-sp logger write service {:keys [id] :as clj-call})

cljdoc builds & hosts documentation for Clojure/Script libraries